@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: simple-sendfile
-version: 0.1.3
-id: simple-sendfile-0.1.3-e110ac0bb50807745cd91d0abbfd3390
+version: 0.2.4
+id: simple-sendfile-0.2.4-d0d1ad7b5347c5b5c77b73be8597470a
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 stability:
 homepage:
 package-url:
+synopsis: Cross platform library for the sendfile system call
 description: Cross platform library for the sendfile system call.
              This library tries to call minimum system calls which
              are the bottleneck of web servers.
@@ -18,23 +19,24 @@ pkgpath: devel/hs-simple-sendfile
 exposed: True
 exposed-modules: Network.Sendfile
 hidden-modules: Network.Sendfile.Fallback Network.Sendfile.Types
-import-dirs: /usr/local/lib/ghc/simple-sendfile-0.1.3
-library-dirs: /usr/local/lib/ghc/simple-sendfile-0.1.3
-hs-libraries: HSsimple-sendfile-0.1.3
+trusted: False
+import-dirs: /usr/local/lib/ghc/simple-sendfile-0.2.4
+library-dirs: /usr/local/lib/ghc/simple-sendfile-0.2.4
+hs-libraries: HSsimple-sendfile-0.2.4
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
-         bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
-         enumerator-0.4.14-63fedf341c69a69125c64fd58230de7c
-         network-2.3.0.5-8b6868c0e6dbf6adced217440d46f03d
-         transformers-0.2.2.0-89265f646be3aed4f502cfc5eccd7c93
+depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
+         conduit-0.4.2-e8d5c4153d76f3672eace08aa0cd55be
+         network-2.3.1.0-e56ec3d5abd17b7b386690bf49d424ab
+         transformers-0.3.0.0-2889ebed7e61112cda7ded5e4c153bcf
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-simple-sendfile-0.1.3/html/simple-sendfile.haddock
-haddock-html: /usr/local/share/doc/hs-simple-sendfile-0.1.3/html
+haddock-interfaces: /usr/local/share/doc/hs-simple-sendfile-0.2.4/html/simple-sendfile.haddock
+haddock-html: /usr/local/share/doc/hs-simple-sendfile-0.2.4/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
